Management commands — django-guardian v1.0.0.beta1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v1.0.0.beta1 documentation »
- API Reference »

# Management commands

class `guardian.management.commands.clean_orphan_obj_perms.` `Command`

  clean_orphan_obj_perms command is a tiny wrapper around `guardian.utils.clean_orphan_obj_perms()`.

  Usage:

      $ python manage.py clean_orphan_obj_perms
      Removed 11 object permission entries with no targets

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v1.0.0.beta1 documentation »
- API Reference »